variable "cluster_name" {
  type        = string
  description = "Name of the cluster"
}

variable "started" {
  type = bool
}

variable "proxmox_image_storage" {
  type = string
}

variable "proxmox_vm_storage" {
  type = string
}

variable "vm_id_prefix" {
  type        = number
  description = "Prefix for the vm ids in the cluster"
}

variable "gateway" {
  type    = string
  default = "10.0.0.1"
}

variable "control_plane_count" {
  type        = number
  description = "Number of nodes in the control plane"
  validation {
    condition     = var.control_plane_count <= 16
    error_message = "Too many control plane nodes"
  }
}

variable "worker_count" {
  type        = number
  description = "Number of worker nodes"
  validation {
    condition     = var.worker_count <= 32
    error_message = "Too many worker nodes"
  }
}

variable "storage_worker_count" {
  type        = number
  description = "Number of storage worker nodes"
  validation {
    condition     = var.storage_worker_count <= 8
    error_message = "Too many storage worker nodes"
  }
}

variable "storage_size" {
  type        = number
  description = "Mounted storage size of the workers, in GB"
  default     = 32
}

variable "cloud_init_file_id" {
  type        = string
  description = "Base cloud-init template"
}

variable "cloud_image_id" {
  type        = string
  description = "Cloud image to use"
}

variable "subnet_cidr" {
  type = string
  # example "10.0.185.0/24"
}

variable "dns_server_ip" {
  type = string
}

variable "ssh_private_key_file" {
  type = string
  description = "Path to private key file. Make sure this matches the public key defined in the cloud init."
}
